pub struct EsiClient { /* private fields */ }Implementations
Sourceimpl EsiClient
impl EsiClient
Build the EVE SSO authorization URL with PKCE.
Returns a PkceChallenge containing the URL to redirect the user to,
the code verifier (needed for exchange_code), and the state parameter
(should be verified on callback).
Sourcepub async fn exchange_code(
&self,
code: &str,
code_verifier: &SecretString,
redirect_uri: &str,
) -> Result<EsiTokens>
pub async fn exchange_code( &self, code: &str, code_verifier: &SecretString, redirect_uri: &str, ) -> Result<EsiTokens>
Exchange an authorization code for tokens.
Sourcepub async fn refresh_token(&self) -> Result<EsiTokens>
pub async fn refresh_token(&self) -> Result<EsiTokens>
Refresh the access token using the stored refresh token.
Uses a dedicated mutex to serialize refresh operations, preventing concurrent callers from racing on the same refresh token.
Sourcepub async fn set_tokens(&self, tokens: EsiTokens)
pub async fn set_tokens(&self, tokens: EsiTokens)
Store tokens (e.g. restored from a database).
Sourcepub async fn get_tokens(&self) -> Option<EsiTokens>
pub async fn get_tokens(&self) -> Option<EsiTokens>
Read the current tokens.
Sourcepub async fn clear_tokens(&self)
pub async fn clear_tokens(&self)
Clear stored tokens (logout).
Sourceimpl EsiClient
impl EsiClient
Sourcepub async fn get_alliance(&self, alliance_id: i64) -> Result<EsiAllianceInfo>
pub async fn get_alliance(&self, alliance_id: i64) -> Result<EsiAllianceInfo>
Fetch alliance info from ESI.
Sourcepub async fn list_alliance_ids(&self) -> Result<Vec<i32>>
pub async fn list_alliance_ids(&self) -> Result<Vec<i32>>
List all alliance IDs.
Sourcepub async fn alliance_corporations(&self, alliance_id: i64) -> Result<Vec<i32>>
pub async fn alliance_corporations(&self, alliance_id: i64) -> Result<Vec<i32>>
Fetch corporation IDs in an alliance.
Sourcepub async fn alliance_icons(&self, alliance_id: i64) -> Result<EsiAllianceIcons>
pub async fn alliance_icons(&self, alliance_id: i64) -> Result<EsiAllianceIcons>
Fetch alliance icon URLs.
Sourcepub async fn alliance_contacts(
&self,
alliance_id: i64,
) -> Result<Vec<EsiContact>>
pub async fn alliance_contacts( &self, alliance_id: i64, ) -> Result<Vec<EsiContact>>
Fetch alliance contacts (authenticated, paginated).
Sourcepub async fn alliance_contact_labels(
&self,
alliance_id: i64,
) -> Result<Vec<EsiContactLabel>>
pub async fn alliance_contact_labels( &self, alliance_id: i64, ) -> Result<Vec<EsiContactLabel>>
Fetch alliance contact labels (authenticated).
Sourceimpl EsiClient
impl EsiClient
Sourcepub async fn get_character(&self, character_id: i64) -> Result<EsiCharacterInfo>
pub async fn get_character(&self, character_id: i64) -> Result<EsiCharacterInfo>
Fetch character info from ESI.
Sourcepub async fn character_affiliation(
&self,
character_ids: &[i64],
) -> Result<Vec<EsiCharacterAffiliation>>
pub async fn character_affiliation( &self, character_ids: &[i64], ) -> Result<Vec<EsiCharacterAffiliation>>
Bulk character affiliation lookup. Auto-chunks at 1000.
Sourcepub async fn character_portrait(
&self,
character_id: i64,
) -> Result<EsiCharacterPortrait>
pub async fn character_portrait( &self, character_id: i64, ) -> Result<EsiCharacterPortrait>
Fetch character portrait URLs.
Sourcepub async fn character_roles(
&self,
character_id: i64,
) -> Result<EsiCharacterRoles>
pub async fn character_roles( &self, character_id: i64, ) -> Result<EsiCharacterRoles>
Fetch character roles (authenticated).
Sourcepub async fn character_titles(
&self,
character_id: i64,
) -> Result<Vec<EsiCharacterTitle>>
pub async fn character_titles( &self, character_id: i64, ) -> Result<Vec<EsiCharacterTitle>>
Fetch character titles (authenticated).
Sourcepub async fn character_standings(
&self,
character_id: i64,
) -> Result<Vec<EsiStanding>>
pub async fn character_standings( &self, character_id: i64, ) -> Result<Vec<EsiStanding>>
Fetch character standings (authenticated).
Sourcepub async fn character_medals(
&self,
character_id: i64,
) -> Result<Vec<EsiCharacterMedal>>
pub async fn character_medals( &self, character_id: i64, ) -> Result<Vec<EsiCharacterMedal>>
Fetch character medals (authenticated).
Sourcepub async fn character_agents_research(
&self,
character_id: i64,
) -> Result<Vec<EsiAgentResearch>>
pub async fn character_agents_research( &self, character_id: i64, ) -> Result<Vec<EsiAgentResearch>>
Fetch character agent research info (authenticated).
Sourcepub async fn character_fatigue(&self, character_id: i64) -> Result<EsiFatigue>
pub async fn character_fatigue(&self, character_id: i64) -> Result<EsiFatigue>
Fetch character jump fatigue (authenticated).
Sourcepub async fn character_fw_stats(
&self,
character_id: i64,
) -> Result<EsiCharacterFwStats>
pub async fn character_fw_stats( &self, character_id: i64, ) -> Result<EsiCharacterFwStats>
Fetch character FW stats (authenticated).
Sourcepub async fn character_cspa_charge(
&self,
character_id: i64,
character_ids: &[i64],
) -> Result<f64>
pub async fn character_cspa_charge( &self, character_id: i64, character_ids: &[i64], ) -> Result<f64>
Calculate CSPA charge cost for contacting characters.
Sourcepub async fn character_corporation_history(
&self,
character_id: i64,
) -> Result<Vec<EsiCorporationHistoryEntry>>
pub async fn character_corporation_history( &self, character_id: i64, ) -> Result<Vec<EsiCorporationHistoryEntry>>
Fetch a character’s corporation history.
Sourcepub async fn character_assets(
&self,
character_id: i64,
) -> Result<Vec<EsiAssetItem>>
pub async fn character_assets( &self, character_id: i64, ) -> Result<Vec<EsiAssetItem>>
Fetch all assets for a character, handling pagination.
Sourcepub async fn character_asset_locations(
&self,
character_id: i64,
item_ids: &[i64],
) -> Result<Vec<EsiAssetLocation>>
pub async fn character_asset_locations( &self, character_id: i64, item_ids: &[i64], ) -> Result<Vec<EsiAssetLocation>>
Resolve character asset item IDs to locations.
Sourcepub async fn character_asset_names(
&self,
character_id: i64,
item_ids: &[i64],
) -> Result<Vec<EsiAssetName>>
pub async fn character_asset_names( &self, character_id: i64, item_ids: &[i64], ) -> Result<Vec<EsiAssetName>>
Resolve character asset item IDs to names. Auto-chunks at 1000.
Sourcepub async fn wallet_balance(&self, character_id: i64) -> Result<Isk>
pub async fn wallet_balance(&self, character_id: i64) -> Result<Isk>
Fetch a character’s ISK balance.
Sourcepub async fn wallet_journal(
&self,
character_id: i64,
) -> Result<Vec<EsiWalletJournalEntry>>
pub async fn wallet_journal( &self, character_id: i64, ) -> Result<Vec<EsiWalletJournalEntry>>
Fetch a character’s wallet journal (paginated).
Sourcepub async fn wallet_transactions(
&self,
character_id: i64,
from_id: Option<i64>,
) -> Result<Vec<EsiWalletTransaction>>
pub async fn wallet_transactions( &self, character_id: i64, from_id: Option<i64>, ) -> Result<Vec<EsiWalletTransaction>>
Fetch a character’s wallet transactions.
Pass from_id to page backwards through older transactions.
Sourcepub async fn character_skills(&self, character_id: i64) -> Result<EsiSkills>
pub async fn character_skills(&self, character_id: i64) -> Result<EsiSkills>
Fetch a character’s trained skills.
Sourcepub async fn character_skillqueue(
&self,
character_id: i64,
) -> Result<Vec<EsiSkillqueueEntry>>
pub async fn character_skillqueue( &self, character_id: i64, ) -> Result<Vec<EsiSkillqueueEntry>>
Fetch a character’s skill queue.
Sourcepub async fn character_attributes(
&self,
character_id: i64,
) -> Result<EsiAttributes>
pub async fn character_attributes( &self, character_id: i64, ) -> Result<EsiAttributes>
Fetch a character’s attributes.
Sourcepub async fn character_industry_jobs(
&self,
character_id: i64,
include_completed: bool,
) -> Result<Vec<EsiIndustryJob>>
pub async fn character_industry_jobs( &self, character_id: i64, include_completed: bool, ) -> Result<Vec<EsiIndustryJob>>
Fetch a character’s industry jobs.
Pass include_completed = true to include completed jobs.
Sourcepub async fn character_blueprints(
&self,
character_id: i64,
) -> Result<Vec<EsiBlueprint>>
pub async fn character_blueprints( &self, character_id: i64, ) -> Result<Vec<EsiBlueprint>>
Fetch a character’s blueprints (paginated).
Sourcepub async fn character_location(&self, character_id: i64) -> Result<EsiLocation>
pub async fn character_location(&self, character_id: i64) -> Result<EsiLocation>
Fetch a character’s current location.
Sourcepub async fn character_ship(&self, character_id: i64) -> Result<EsiShip>
pub async fn character_ship(&self, character_id: i64) -> Result<EsiShip>
Fetch a character’s current ship.
Sourcepub async fn character_online(
&self,
character_id: i64,
) -> Result<EsiOnlineStatus>
pub async fn character_online( &self, character_id: i64, ) -> Result<EsiOnlineStatus>
Fetch a character’s online status.
Sourcepub async fn character_clones(&self, character_id: i64) -> Result<EsiClones>
pub async fn character_clones(&self, character_id: i64) -> Result<EsiClones>
Fetch a character’s clones.
Sourcepub async fn character_implants(&self, character_id: i64) -> Result<Vec<i32>>
pub async fn character_implants(&self, character_id: i64) -> Result<Vec<i32>>
Fetch a character’s active implants.
Sourcepub async fn character_loyalty_points(
&self,
character_id: i64,
) -> Result<Vec<EsiLoyaltyPoints>>
pub async fn character_loyalty_points( &self, character_id: i64, ) -> Result<Vec<EsiLoyaltyPoints>>
Fetch a character’s LP balances.
Sourcepub async fn character_planets(
&self,
character_id: i64,
) -> Result<Vec<EsiPlanetSummary>>
pub async fn character_planets( &self, character_id: i64, ) -> Result<Vec<EsiPlanetSummary>>
Fetch a character’s planetary colonies.
Sourcepub async fn character_planet_detail(
&self,
character_id: i64,
planet_id: i32,
) -> Result<EsiPlanetDetail>
pub async fn character_planet_detail( &self, character_id: i64, planet_id: i32, ) -> Result<EsiPlanetDetail>
Fetch detailed layout of a planetary colony.
Sourcepub async fn character_mining_ledger(
&self,
character_id: i64,
) -> Result<Vec<EsiMiningEntry>>
pub async fn character_mining_ledger( &self, character_id: i64, ) -> Result<Vec<EsiMiningEntry>>
Fetch a character’s personal mining ledger (paginated).
Sourcepub async fn character_contact_notifications(
&self,
character_id: i64,
) -> Result<Vec<EsiContactNotification>>
pub async fn character_contact_notifications( &self, character_id: i64, ) -> Result<Vec<EsiContactNotification>>
Fetch a character’s contact notifications.
Sourcepub async fn character_opportunities(
&self,
character_id: i64,
) -> Result<Vec<EsiCompletedOpportunity>>
pub async fn character_opportunities( &self, character_id: i64, ) -> Result<Vec<EsiCompletedOpportunity>>
Fetch completed opportunities for a character (authenticated).
Sourceimpl EsiClient
impl EsiClient
Sourcepub async fn character_contracts(
&self,
character_id: i64,
) -> Result<Vec<EsiContract>>
pub async fn character_contracts( &self, character_id: i64, ) -> Result<Vec<EsiContract>>
Fetch a character’s contracts (paginated).
Sourcepub async fn character_contract_items(
&self,
character_id: i64,
contract_id: i64,
) -> Result<Vec<EsiContractItem>>
pub async fn character_contract_items( &self, character_id: i64, contract_id: i64, ) -> Result<Vec<EsiContractItem>>
Fetch items in a specific contract.
Sourcepub async fn character_contract_bids(
&self,
character_id: i64,
contract_id: i64,
) -> Result<Vec<EsiContractBid>>
pub async fn character_contract_bids( &self, character_id: i64, contract_id: i64, ) -> Result<Vec<EsiContractBid>>
Fetch bids on a specific auction contract.
Sourcepub async fn character_orders(
&self,
character_id: i64,
) -> Result<Vec<EsiCharacterOrder>>
pub async fn character_orders( &self, character_id: i64, ) -> Result<Vec<EsiCharacterOrder>>
Fetch a character’s active market orders.
Sourcepub async fn character_order_history(
&self,
character_id: i64,
) -> Result<Vec<EsiCharacterOrder>>
pub async fn character_order_history( &self, character_id: i64, ) -> Result<Vec<EsiCharacterOrder>>
Fetch a character’s order history (paginated).
Sourcepub async fn character_fittings(
&self,
character_id: i64,
) -> Result<Vec<EsiFitting>>
pub async fn character_fittings( &self, character_id: i64, ) -> Result<Vec<EsiFitting>>
Fetch a character’s saved fittings.
Sourcepub async fn create_fitting(
&self,
character_id: i64,
fitting: &EsiNewFitting,
) -> Result<i64>
pub async fn create_fitting( &self, character_id: i64, fitting: &EsiNewFitting, ) -> Result<i64>
Create a new fitting for a character. Returns the new fitting ID.
Sourcepub async fn delete_fitting(
&self,
character_id: i64,
fitting_id: i64,
) -> Result<()>
pub async fn delete_fitting( &self, character_id: i64, fitting_id: i64, ) -> Result<()>
Delete a fitting. Returns () on success (204).
Sourcepub async fn character_mail(
&self,
character_id: i64,
labels: Option<&[i32]>,
) -> Result<Vec<EsiMailHeader>>
pub async fn character_mail( &self, character_id: i64, labels: Option<&[i32]>, ) -> Result<Vec<EsiMailHeader>>
Fetch a character’s mail headers (first batch).
Pass labels to filter by label IDs.
Sourcepub async fn character_mail_before(
&self,
character_id: i64,
last_mail_id: i64,
) -> Result<Vec<EsiMailHeader>>
pub async fn character_mail_before( &self, character_id: i64, last_mail_id: i64, ) -> Result<Vec<EsiMailHeader>>
Fetch mail headers before a given mail ID (cursor pagination).
Sourcepub async fn character_mail_body(
&self,
character_id: i64,
mail_id: i64,
) -> Result<EsiMailBody>
pub async fn character_mail_body( &self, character_id: i64, mail_id: i64, ) -> Result<EsiMailBody>
Fetch a single mail body.
Sourcepub async fn send_mail(
&self,
character_id: i64,
mail: &EsiNewMail,
) -> Result<i32>
pub async fn send_mail( &self, character_id: i64, mail: &EsiNewMail, ) -> Result<i32>
Send a mail. Returns the new mail ID.
Sourcepub async fn character_mail_labels(
&self,
character_id: i64,
) -> Result<EsiMailLabels>
pub async fn character_mail_labels( &self, character_id: i64, ) -> Result<EsiMailLabels>
Fetch a character’s mail labels.
Sourcepub async fn create_mail_label(
&self,
character_id: i64,
label: &EsiNewMailLabel,
) -> Result<i32>
pub async fn create_mail_label( &self, character_id: i64, label: &EsiNewMailLabel, ) -> Result<i32>
Create a new mail label. Returns the label ID.
Sourcepub async fn delete_mail_label(
&self,
character_id: i64,
label_id: i32,
) -> Result<()>
pub async fn delete_mail_label( &self, character_id: i64, label_id: i32, ) -> Result<()>
Delete a mail label.
Sourcepub async fn character_mailing_lists(
&self,
character_id: i64,
) -> Result<Vec<EsiMailingList>>
pub async fn character_mailing_lists( &self, character_id: i64, ) -> Result<Vec<EsiMailingList>>
Fetch a character’s mailing lists (authenticated).
Sourcepub async fn update_mail(
&self,
character_id: i64,
mail_id: i64,
update: &EsiMailUpdate,
) -> Result<()>
pub async fn update_mail( &self, character_id: i64, mail_id: i64, update: &EsiMailUpdate, ) -> Result<()>
Update mail metadata (read status, labels).
Sourcepub async fn character_notifications(
&self,
character_id: i64,
) -> Result<Vec<EsiNotification>>
pub async fn character_notifications( &self, character_id: i64, ) -> Result<Vec<EsiNotification>>
Fetch a character’s notifications.
Sourcepub async fn character_contacts(
&self,
character_id: i64,
) -> Result<Vec<EsiContact>>
pub async fn character_contacts( &self, character_id: i64, ) -> Result<Vec<EsiContact>>
Fetch a character’s contacts (paginated).
Sourcepub async fn character_contact_labels(
&self,
character_id: i64,
) -> Result<Vec<EsiContactLabel>>
pub async fn character_contact_labels( &self, character_id: i64, ) -> Result<Vec<EsiContactLabel>>
Fetch a character’s contact labels.
Sourcepub async fn add_contacts(
&self,
character_id: i64,
standing: f64,
contact_ids: &[i64],
label_ids: Option<&[i64]>,
watched: Option<bool>,
) -> Result<Vec<i32>>
pub async fn add_contacts( &self, character_id: i64, standing: f64, contact_ids: &[i64], label_ids: Option<&[i64]>, watched: Option<bool>, ) -> Result<Vec<i32>>
Add contacts to a character. Returns added contact IDs.
Sourcepub async fn edit_contacts(
&self,
character_id: i64,
standing: f64,
contact_ids: &[i64],
label_ids: Option<&[i64]>,
watched: Option<bool>,
) -> Result<()>
pub async fn edit_contacts( &self, character_id: i64, standing: f64, contact_ids: &[i64], label_ids: Option<&[i64]>, watched: Option<bool>, ) -> Result<()>
Edit contacts for a character.
Sourcepub async fn delete_contacts(
&self,
character_id: i64,
contact_ids: &[i64],
) -> Result<()>
pub async fn delete_contacts( &self, character_id: i64, contact_ids: &[i64], ) -> Result<()>
Delete contacts from a character.
Sourcepub async fn character_calendar(
&self,
character_id: i64,
from_event: Option<i32>,
) -> Result<Vec<EsiCalendarEvent>>
pub async fn character_calendar( &self, character_id: i64, from_event: Option<i32>, ) -> Result<Vec<EsiCalendarEvent>>
Fetch a character’s upcoming calendar events.
Pass from_event to page backwards through older events.
Sourcepub async fn character_calendar_event(
&self,
character_id: i64,
event_id: i64,
) -> Result<EsiCalendarEventDetail>
pub async fn character_calendar_event( &self, character_id: i64, event_id: i64, ) -> Result<EsiCalendarEventDetail>
Fetch details of a specific calendar event.
Sourcepub async fn set_event_response(
&self,
character_id: i64,
event_id: i64,
response: &str,
) -> Result<()>
pub async fn set_event_response( &self, character_id: i64, event_id: i64, response: &str, ) -> Result<()>
Set a character’s response to a calendar event.
Sourcepub async fn event_attendees(
&self,
character_id: i64,
event_id: i64,
) -> Result<Vec<EsiEventAttendee>>
pub async fn event_attendees( &self, character_id: i64, event_id: i64, ) -> Result<Vec<EsiEventAttendee>>
Fetch attendees for a calendar event (authenticated).
Sourcepub async fn search(
&self,
search: &str,
categories: &str,
strict: bool,
) -> Result<EsiSearchResult>
pub async fn search( &self, search: &str, categories: &str, strict: bool, ) -> Result<EsiSearchResult>
Search for entities by name (public, unauthenticated).
categories is a comma-separated list of categories to search
(e.g. "solar_system,station").
Sourcepub async fn character_search(
&self,
character_id: i64,
search: &str,
categories: &str,
strict: bool,
) -> Result<EsiSearchResult>
pub async fn character_search( &self, character_id: i64, search: &str, categories: &str, strict: bool, ) -> Result<EsiSearchResult>
Authenticated search for entities by name.
Sourceimpl EsiClient
impl EsiClient
Sourcepub async fn get_corporation(
&self,
corporation_id: i64,
) -> Result<EsiCorporationInfo>
pub async fn get_corporation( &self, corporation_id: i64, ) -> Result<EsiCorporationInfo>
Fetch corporation info from ESI.
Sourcepub async fn corp_alliance_history(
&self,
corporation_id: i64,
) -> Result<Vec<EsiAllianceHistoryEntry>>
pub async fn corp_alliance_history( &self, corporation_id: i64, ) -> Result<Vec<EsiAllianceHistoryEntry>>
Fetch a corporation’s alliance history.
Sourcepub async fn list_npc_corp_ids(&self) -> Result<Vec<i32>>
pub async fn list_npc_corp_ids(&self) -> Result<Vec<i32>>
List NPC corporation IDs.
Sourcepub async fn corp_wallet_balances(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCorpWalletDivision>>
pub async fn corp_wallet_balances( &self, corporation_id: i64, ) -> Result<Vec<EsiCorpWalletDivision>>
Fetch corporation wallet division balances.
Sourcepub async fn corp_wallet_journal(
&self,
corporation_id: i64,
division: i32,
from_id: Option<i64>,
) -> Result<Vec<EsiWalletJournalEntry>>
pub async fn corp_wallet_journal( &self, corporation_id: i64, division: i32, from_id: Option<i64>, ) -> Result<Vec<EsiWalletJournalEntry>>
Fetch corporation wallet journal for a division.
Pass from_id to page backwards through older journal entries.
Sourcepub async fn corp_wallet_transactions(
&self,
corporation_id: i64,
division: i32,
from_id: Option<i64>,
) -> Result<Vec<EsiWalletTransaction>>
pub async fn corp_wallet_transactions( &self, corporation_id: i64, division: i32, from_id: Option<i64>, ) -> Result<Vec<EsiWalletTransaction>>
Fetch corporation wallet transactions for a division.
Pass from_id to page backwards through older transactions.
Sourcepub async fn corp_assets(
&self,
corporation_id: i64,
) -> Result<Vec<EsiAssetItem>>
pub async fn corp_assets( &self, corporation_id: i64, ) -> Result<Vec<EsiAssetItem>>
Fetch corporation assets (paginated).
Sourcepub async fn corp_asset_names(
&self,
corporation_id: i64,
item_ids: &[i64],
) -> Result<Vec<EsiAssetName>>
pub async fn corp_asset_names( &self, corporation_id: i64, item_ids: &[i64], ) -> Result<Vec<EsiAssetName>>
Resolve corporation asset item IDs to names.
Sourcepub async fn corp_asset_locations(
&self,
corporation_id: i64,
item_ids: &[i64],
) -> Result<Vec<EsiAssetLocation>>
pub async fn corp_asset_locations( &self, corporation_id: i64, item_ids: &[i64], ) -> Result<Vec<EsiAssetLocation>>
Resolve corporation asset item IDs to locations.
Sourcepub async fn corp_industry_jobs(
&self,
corporation_id: i64,
include_completed: bool,
) -> Result<Vec<EsiIndustryJob>>
pub async fn corp_industry_jobs( &self, corporation_id: i64, include_completed: bool, ) -> Result<Vec<EsiIndustryJob>>
Fetch corporation industry jobs (paginated).
Pass include_completed = true to include completed jobs.
Sourcepub async fn corp_blueprints(
&self,
corporation_id: i64,
) -> Result<Vec<EsiBlueprint>>
pub async fn corp_blueprints( &self, corporation_id: i64, ) -> Result<Vec<EsiBlueprint>>
Fetch corporation blueprints (paginated).
Sourcepub async fn corp_contracts(
&self,
corporation_id: i64,
) -> Result<Vec<EsiContract>>
pub async fn corp_contracts( &self, corporation_id: i64, ) -> Result<Vec<EsiContract>>
Fetch corporation contracts (paginated).
Sourcepub async fn corp_contract_bids(
&self,
corporation_id: i64,
contract_id: i64,
) -> Result<Vec<EsiContractBid>>
pub async fn corp_contract_bids( &self, corporation_id: i64, contract_id: i64, ) -> Result<Vec<EsiContractBid>>
Fetch bids on a corporation contract.
Sourcepub async fn corp_contract_items(
&self,
corporation_id: i64,
contract_id: i64,
) -> Result<Vec<EsiContractItem>>
pub async fn corp_contract_items( &self, corporation_id: i64, contract_id: i64, ) -> Result<Vec<EsiContractItem>>
Fetch items in a corporation contract.
Sourcepub async fn corp_orders(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCharacterOrder>>
pub async fn corp_orders( &self, corporation_id: i64, ) -> Result<Vec<EsiCharacterOrder>>
Fetch corporation active market orders.
Sourcepub async fn corp_order_history(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCharacterOrder>>
pub async fn corp_order_history( &self, corporation_id: i64, ) -> Result<Vec<EsiCharacterOrder>>
Fetch corporation order history (paginated).
Sourcepub async fn corp_members(&self, corporation_id: i64) -> Result<Vec<i64>>
pub async fn corp_members(&self, corporation_id: i64) -> Result<Vec<i64>>
Fetch corporation member IDs.
Sourcepub async fn corp_member_titles(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCorpMemberTitle>>
pub async fn corp_member_titles( &self, corporation_id: i64, ) -> Result<Vec<EsiCorpMemberTitle>>
Fetch corporation member titles.
Sourcepub async fn corp_member_roles(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCorpMemberRole>>
pub async fn corp_member_roles( &self, corporation_id: i64, ) -> Result<Vec<EsiCorpMemberRole>>
Fetch corporation member roles.
Sourcepub async fn corp_member_tracking(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCorpMemberTracking>>
pub async fn corp_member_tracking( &self, corporation_id: i64, ) -> Result<Vec<EsiCorpMemberTracking>>
Fetch corporation member tracking info.
Sourcepub async fn corp_member_limit(&self, corporation_id: i64) -> Result<i32>
pub async fn corp_member_limit(&self, corporation_id: i64) -> Result<i32>
Fetch corporation member limit.
Sourcepub async fn corp_structures(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCorpStructure>>
pub async fn corp_structures( &self, corporation_id: i64, ) -> Result<Vec<EsiCorpStructure>>
Fetch corporation structures (paginated).
Sourcepub async fn corp_starbases(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCorpStarbase>>
pub async fn corp_starbases( &self, corporation_id: i64, ) -> Result<Vec<EsiCorpStarbase>>
Fetch corporation starbases (POSes).
Sourcepub async fn corp_starbase_detail(
&self,
corporation_id: i64,
starbase_id: i64,
system_id: i32,
) -> Result<EsiCorpStarbaseDetail>
pub async fn corp_starbase_detail( &self, corporation_id: i64, starbase_id: i64, system_id: i32, ) -> Result<EsiCorpStarbaseDetail>
Fetch detailed configuration of a specific starbase.
Sourcepub async fn corp_contacts(
&self,
corporation_id: i64,
) -> Result<Vec<EsiContact>>
pub async fn corp_contacts( &self, corporation_id: i64, ) -> Result<Vec<EsiContact>>
Fetch corporation contacts (authenticated, paginated).
Sourcepub async fn corp_contact_labels(
&self,
corporation_id: i64,
) -> Result<Vec<EsiContactLabel>>
pub async fn corp_contact_labels( &self, corporation_id: i64, ) -> Result<Vec<EsiContactLabel>>
Fetch corporation contact labels (authenticated).
Sourcepub async fn corp_container_logs(
&self,
corporation_id: i64,
) -> Result<Vec<EsiContainerLog>>
pub async fn corp_container_logs( &self, corporation_id: i64, ) -> Result<Vec<EsiContainerLog>>
Fetch corporation container audit logs (authenticated, paginated).
Sourcepub async fn corp_customs_offices(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCustomsOffice>>
pub async fn corp_customs_offices( &self, corporation_id: i64, ) -> Result<Vec<EsiCustomsOffice>>
Fetch corporation customs offices (authenticated, paginated).
Sourcepub async fn corp_divisions(
&self,
corporation_id: i64,
) -> Result<EsiCorpDivisions>
pub async fn corp_divisions( &self, corporation_id: i64, ) -> Result<EsiCorpDivisions>
Fetch corporation divisions.
Sourcepub async fn corp_facilities(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCorpFacility>>
pub async fn corp_facilities( &self, corporation_id: i64, ) -> Result<Vec<EsiCorpFacility>>
Fetch corporation facilities.
Sourcepub async fn corp_fw_stats(&self, corporation_id: i64) -> Result<EsiCorpFwStats>
pub async fn corp_fw_stats(&self, corporation_id: i64) -> Result<EsiCorpFwStats>
Fetch corporation FW stats.
Sourcepub async fn corp_icons(&self, corporation_id: i64) -> Result<EsiCorpIcons>
pub async fn corp_icons(&self, corporation_id: i64) -> Result<EsiCorpIcons>
Fetch corporation icon URLs.
Sourcepub async fn corp_medals(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCorpMedal>>
pub async fn corp_medals( &self, corporation_id: i64, ) -> Result<Vec<EsiCorpMedal>>
Fetch corporation medals (paginated).
Sourcepub async fn corp_medals_issued(
&self,
corporation_id: i64,
) -> Result<Vec<EsiIssuedMedal>>
pub async fn corp_medals_issued( &self, corporation_id: i64, ) -> Result<Vec<EsiIssuedMedal>>
Fetch issued medals (paginated).
Sourcepub async fn corp_roles_history(
&self,
corporation_id: i64,
) -> Result<Vec<EsiRoleHistory>>
pub async fn corp_roles_history( &self, corporation_id: i64, ) -> Result<Vec<EsiRoleHistory>>
Fetch corporation role change history (paginated).
Fetch corporation shareholders (paginated).
Sourcepub async fn corp_standings(
&self,
corporation_id: i64,
) -> Result<Vec<EsiStanding>>
pub async fn corp_standings( &self, corporation_id: i64, ) -> Result<Vec<EsiStanding>>
Fetch corporation standings (paginated).
Sourcepub async fn corp_titles(
&self,
corporation_id: i64,
) -> Result<Vec<EsiCorpTitle>>
pub async fn corp_titles( &self, corporation_id: i64, ) -> Result<Vec<EsiCorpTitle>>
Fetch corporation titles.
Sourcepub async fn corp_mining_extractions(
&self,
corporation_id: i64,
) -> Result<Vec<EsiMiningExtraction>>
pub async fn corp_mining_extractions( &self, corporation_id: i64, ) -> Result<Vec<EsiMiningExtraction>>
Fetch moon mining extractions (paginated).
Sourcepub async fn corp_mining_observers(
&self,
corporation_id: i64,
) -> Result<Vec<EsiMiningObserver>>
pub async fn corp_mining_observers( &self, corporation_id: i64, ) -> Result<Vec<EsiMiningObserver>>
Fetch mining observers (paginated).
Sourcepub async fn corp_mining_observer_details(
&self,
corporation_id: i64,
observer_id: i64,
) -> Result<Vec<EsiMiningObserverEntry>>
pub async fn corp_mining_observer_details( &self, corporation_id: i64, observer_id: i64, ) -> Result<Vec<EsiMiningObserverEntry>>
Fetch mining observer details (paginated).
Sourceimpl EsiClient
impl EsiClient
Sourcepub async fn character_fleet(
&self,
character_id: i64,
) -> Result<EsiCharacterFleet>
pub async fn character_fleet( &self, character_id: i64, ) -> Result<EsiCharacterFleet>
Fetch a character’s current fleet (authenticated).
Sourcepub async fn get_fleet(&self, fleet_id: i64) -> Result<EsiFleetInfo>
pub async fn get_fleet(&self, fleet_id: i64) -> Result<EsiFleetInfo>
Fetch fleet information.
Sourcepub async fn fleet_members(&self, fleet_id: i64) -> Result<Vec<EsiFleetMember>>
pub async fn fleet_members(&self, fleet_id: i64) -> Result<Vec<EsiFleetMember>>
Fetch fleet members.
Sourcepub async fn fleet_wings(&self, fleet_id: i64) -> Result<Vec<EsiFleetWing>>
pub async fn fleet_wings(&self, fleet_id: i64) -> Result<Vec<EsiFleetWing>>
Fetch fleet wings and squads.
Sourcepub async fn update_fleet(
&self,
fleet_id: i64,
settings: &EsiFleetUpdate,
) -> Result<()>
pub async fn update_fleet( &self, fleet_id: i64, settings: &EsiFleetUpdate, ) -> Result<()>
Update fleet settings.
Sourcepub async fn invite_to_fleet(
&self,
fleet_id: i64,
invitation: &EsiFleetInvitation,
) -> Result<()>
pub async fn invite_to_fleet( &self, fleet_id: i64, invitation: &EsiFleetInvitation, ) -> Result<()>
Invite a character to a fleet.
Sourcepub async fn kick_fleet_member(
&self,
fleet_id: i64,
member_id: i64,
) -> Result<()>
pub async fn kick_fleet_member( &self, fleet_id: i64, member_id: i64, ) -> Result<()>
Kick a member from a fleet.
Sourcepub async fn move_fleet_member(
&self,
fleet_id: i64,
member_id: i64,
movement: &EsiFleetMovement,
) -> Result<()>
pub async fn move_fleet_member( &self, fleet_id: i64, member_id: i64, movement: &EsiFleetMovement, ) -> Result<()>
Move a fleet member to a different wing/squad/role.
Sourcepub async fn create_fleet_wing(
&self,
fleet_id: i64,
) -> Result<EsiFleetWingCreated>
pub async fn create_fleet_wing( &self, fleet_id: i64, ) -> Result<EsiFleetWingCreated>
Create a fleet wing. Returns the wing ID.
Sourcepub async fn rename_fleet_wing(
&self,
fleet_id: i64,
wing_id: i64,
name: &str,
) -> Result<()>
pub async fn rename_fleet_wing( &self, fleet_id: i64, wing_id: i64, name: &str, ) -> Result<()>
Rename a fleet wing.
Sourcepub async fn delete_fleet_wing(&self, fleet_id: i64, wing_id: i64) -> Result<()>
pub async fn delete_fleet_wing(&self, fleet_id: i64, wing_id: i64) -> Result<()>
Delete a fleet wing.
Sourcepub async fn create_fleet_squad(
&self,
fleet_id: i64,
wing_id: i64,
) -> Result<EsiFleetSquadCreated>
pub async fn create_fleet_squad( &self, fleet_id: i64, wing_id: i64, ) -> Result<EsiFleetSquadCreated>
Create a fleet squad. Returns the squad ID.
Sourceimpl EsiClient
impl EsiClient
Sourcepub async fn get_killmail(
&self,
killmail_id: i64,
killmail_hash: &str,
) -> Result<Value>
pub async fn get_killmail( &self, killmail_id: i64, killmail_hash: &str, ) -> Result<Value>
Fetch a single killmail by ID and hash, returning the raw JSON value.
Sourcepub async fn get_killmail_typed(
&self,
killmail_id: i64,
killmail_hash: &str,
) -> Result<EsiKillmail>
pub async fn get_killmail_typed( &self, killmail_id: i64, killmail_hash: &str, ) -> Result<EsiKillmail>
Fetch a single killmail by ID and hash, returning a typed struct.
Sourcepub async fn character_killmails(
&self,
character_id: i64,
) -> Result<Vec<EsiKillmailRef>>
pub async fn character_killmails( &self, character_id: i64, ) -> Result<Vec<EsiKillmailRef>>
Fetch recent killmails for a character (authenticated, paginated).
Sourcepub async fn corporation_killmails(
&self,
corporation_id: i64,
) -> Result<Vec<EsiKillmailRef>>
pub async fn corporation_killmails( &self, corporation_id: i64, ) -> Result<Vec<EsiKillmailRef>>
Fetch recent killmails for a corporation (authenticated, paginated).
Sourceimpl EsiClient
impl EsiClient
Sourcepub async fn market_history(
&self,
region_id: i32,
type_id: i32,
) -> Result<Vec<EsiMarketHistoryEntry>>
pub async fn market_history( &self, region_id: i32, type_id: i32, ) -> Result<Vec<EsiMarketHistoryEntry>>
Fetch market history for a type in a region.
Sourcepub async fn market_orders(
&self,
region_id: i32,
type_id: i32,
order_type: Option<&str>,
) -> Result<Vec<EsiMarketOrder>>
pub async fn market_orders( &self, region_id: i32, type_id: i32, order_type: Option<&str>, ) -> Result<Vec<EsiMarketOrder>>
Fetch all market orders for a type in a region, handling pagination.
order_type can be "all" (default), "buy", or "sell".
Sourcepub async fn market_prices(&self) -> Result<Vec<EsiMarketPrice>>
pub async fn market_prices(&self) -> Result<Vec<EsiMarketPrice>>
Fetch global average and adjusted prices for all types.
Sourcepub async fn market_type_ids(&self, region_id: i32) -> Result<Vec<i32>>
pub async fn market_type_ids(&self, region_id: i32) -> Result<Vec<i32>>
List all type IDs with active market orders in a region (paginated).
Sourcepub async fn market_group_ids(&self) -> Result<Vec<i32>>
pub async fn market_group_ids(&self) -> Result<Vec<i32>>
List all market group IDs.
Sourcepub async fn get_market_group(
&self,
market_group_id: i32,
) -> Result<EsiMarketGroupInfo>
pub async fn get_market_group( &self, market_group_id: i32, ) -> Result<EsiMarketGroupInfo>
Fetch market group info.
Sourcepub async fn structure_orders(
&self,
structure_id: i64,
) -> Result<Vec<EsiMarketOrder>>
pub async fn structure_orders( &self, structure_id: i64, ) -> Result<Vec<EsiMarketOrder>>
Fetch market orders at a structure (authenticated, paginated).
Sourceimpl EsiClient
impl EsiClient
Sourcepub async fn get_dogma_attribute(
&self,
attribute_id: i32,
) -> Result<EsiDogmaAttribute>
pub async fn get_dogma_attribute( &self, attribute_id: i32, ) -> Result<EsiDogmaAttribute>
Fetch a dogma attribute by ID.
Sourcepub async fn get_dogma_effect(&self, effect_id: i32) -> Result<EsiDogmaEffect>
pub async fn get_dogma_effect(&self, effect_id: i32) -> Result<EsiDogmaEffect>
Fetch a dogma effect by ID.
Sourcepub async fn get_dynamic_item(
&self,
type_id: i32,
item_id: i64,
) -> Result<EsiDynamicItem>
pub async fn get_dynamic_item( &self, type_id: i32, item_id: i64, ) -> Result<EsiDynamicItem>
Fetch a mutated (dynamic) item’s stats.
Sourcepub async fn list_dogma_attribute_ids(&self) -> Result<Vec<i32>>
pub async fn list_dogma_attribute_ids(&self) -> Result<Vec<i32>>
List all dogma attribute IDs.
Sourcepub async fn list_dogma_effect_ids(&self) -> Result<Vec<i32>>
pub async fn list_dogma_effect_ids(&self) -> Result<Vec<i32>>
List all dogma effect IDs.
Sourcepub async fn opportunity_group_ids(&self) -> Result<Vec<i32>>
pub async fn opportunity_group_ids(&self) -> Result<Vec<i32>>
Fetch all opportunity group IDs.
Sourcepub async fn opportunity_task_ids(&self) -> Result<Vec<i32>>
pub async fn opportunity_task_ids(&self) -> Result<Vec<i32>>
Fetch all opportunity task IDs.
Sourcepub async fn list_war_ids(&self, max_war_id: Option<i32>) -> Result<Vec<i32>>
pub async fn list_war_ids(&self, max_war_id: Option<i32>) -> Result<Vec<i32>>
List active war IDs (paginated).
Pass max_war_id to page backwards from a specific war ID.
Sourcepub async fn war_killmails(&self, war_id: i32) -> Result<Vec<EsiKillmailRef>>
pub async fn war_killmails(&self, war_id: i32) -> Result<Vec<EsiKillmailRef>>
Fetch killmails for a war (paginated).
Sourcepub async fn fw_stats(&self) -> Result<Vec<EsiFwFactionStats>>
pub async fn fw_stats(&self) -> Result<Vec<EsiFwFactionStats>>
Fetch faction warfare statistics.
Sourcepub async fn fw_systems(&self) -> Result<Vec<EsiFwSystem>>
pub async fn fw_systems(&self) -> Result<Vec<EsiFwSystem>>
Fetch faction warfare contested systems.
Sourcepub async fn fw_leaderboards(&self) -> Result<EsiFwLeaderboards>
pub async fn fw_leaderboards(&self) -> Result<EsiFwLeaderboards>
Fetch faction warfare leaderboards.
Sourcepub async fn fw_character_leaderboards(
&self,
) -> Result<EsiFwCharacterLeaderboards>
pub async fn fw_character_leaderboards( &self, ) -> Result<EsiFwCharacterLeaderboards>
Fetch character FW leaderboards.
Sourcepub async fn fw_corporation_leaderboards(
&self,
) -> Result<EsiFwCorporationLeaderboards>
pub async fn fw_corporation_leaderboards( &self, ) -> Result<EsiFwCorporationLeaderboards>
Fetch corporation FW leaderboards.
Sourcepub async fn insurance_prices(&self) -> Result<Vec<EsiInsurancePrice>>
pub async fn insurance_prices(&self) -> Result<Vec<EsiInsurancePrice>>
Fetch insurance prices for all ship types.
Sourcepub async fn incursions(&self) -> Result<Vec<EsiIncursion>>
pub async fn incursions(&self) -> Result<Vec<EsiIncursion>>
Fetch active incursions.
Sourcepub async fn server_status(&self) -> Result<EsiServerStatus>
pub async fn server_status(&self) -> Result<EsiServerStatus>
Fetch server status (player count, server version).
Sourcepub async fn loyalty_store_offers(
&self,
corporation_id: i64,
) -> Result<Vec<EsiLoyaltyStoreOffer>>
pub async fn loyalty_store_offers( &self, corporation_id: i64, ) -> Result<Vec<EsiLoyaltyStoreOffer>>
Fetch LP store offers for a corporation (public, no auth).
Sourcepub async fn industry_facilities(&self) -> Result<Vec<EsiIndustryFacility>>
pub async fn industry_facilities(&self) -> Result<Vec<EsiIndustryFacility>>
Fetch public industry facilities.
Sourcepub async fn industry_systems(&self) -> Result<Vec<EsiIndustrySystem>>
pub async fn industry_systems(&self) -> Result<Vec<EsiIndustrySystem>>
Fetch industry system cost indices.
Sourcepub async fn public_contracts(&self, region_id: i32) -> Result<Vec<EsiContract>>
pub async fn public_contracts(&self, region_id: i32) -> Result<Vec<EsiContract>>
Fetch public contracts in a region (paginated).
Sourcepub async fn public_contract_bids(
&self,
contract_id: i64,
) -> Result<Vec<EsiContractBid>>
pub async fn public_contract_bids( &self, contract_id: i64, ) -> Result<Vec<EsiContractBid>>
Fetch bids on a public contract (paginated).
Sourcepub async fn public_contract_items(
&self,
contract_id: i64,
) -> Result<Vec<EsiContractItem>>
pub async fn public_contract_items( &self, contract_id: i64, ) -> Result<Vec<EsiContractItem>>
Fetch items in a public contract (paginated).
Sourcepub async fn ui_autopilot_waypoint(
&self,
destination_id: i64,
add_to_beginning: bool,
clear_other_waypoints: bool,
) -> Result<()>
pub async fn ui_autopilot_waypoint( &self, destination_id: i64, add_to_beginning: bool, clear_other_waypoints: bool, ) -> Result<()>
Set an autopilot waypoint.
Sourcepub async fn ui_open_contract_window(&self, contract_id: i64) -> Result<()>
pub async fn ui_open_contract_window(&self, contract_id: i64) -> Result<()>
Open the contract window in the client.
Sourcepub async fn ui_open_info_window(&self, target_id: i64) -> Result<()>
pub async fn ui_open_info_window(&self, target_id: i64) -> Result<()>
Open the info window in the client.
Sourcepub async fn ui_open_market_details(&self, type_id: i32) -> Result<()>
pub async fn ui_open_market_details(&self, type_id: i32) -> Result<()>
Open the market details window in the client.
Sourcepub async fn ui_open_new_mail(&self, new_mail: &EsiNewMailWindow) -> Result<()>
pub async fn ui_open_new_mail(&self, new_mail: &EsiNewMailWindow) -> Result<()>
Open the new mail window in the client.
Sourceimpl EsiClient
impl EsiClient
Sourcepub async fn resolve_names(&self, ids: &[i64]) -> Result<Vec<EsiResolvedName>>
pub async fn resolve_names(&self, ids: &[i64]) -> Result<Vec<EsiResolvedName>>
Resolve a set of IDs to names and categories.
Automatically chunks requests into batches of 1000 (the ESI limit).
Sourcepub async fn resolve_ids(&self, names: &[String]) -> Result<EsiResolvedIds>
pub async fn resolve_ids(&self, names: &[String]) -> Result<EsiResolvedIds>
Resolve names to IDs (reverse of resolve_names).
Automatically chunks requests into batches of 500 (the ESI limit).
Sourcepub async fn get_structure(&self, structure_id: i64) -> Result<EsiStructureInfo>
pub async fn get_structure(&self, structure_id: i64) -> Result<EsiStructureInfo>
Fetch info about a player-owned structure.
Sourcepub async fn get_type(&self, type_id: i32) -> Result<EsiTypeInfo>
pub async fn get_type(&self, type_id: i32) -> Result<EsiTypeInfo>
Fetch detailed information about an inventory type.
Sourcepub async fn list_type_ids(&self) -> Result<Vec<i32>>
pub async fn list_type_ids(&self) -> Result<Vec<i32>>
List all type IDs (paginated).
Sourcepub async fn get_group(&self, group_id: i32) -> Result<EsiGroupInfo>
pub async fn get_group(&self, group_id: i32) -> Result<EsiGroupInfo>
Fetch inventory group info.
Sourcepub async fn get_category(&self, category_id: i32) -> Result<EsiCategoryInfo>
pub async fn get_category(&self, category_id: i32) -> Result<EsiCategoryInfo>
Fetch inventory category info.
Sourcepub async fn get_system(&self, system_id: i32) -> Result<EsiSolarSystemInfo>
pub async fn get_system(&self, system_id: i32) -> Result<EsiSolarSystemInfo>
Fetch solar system info.
Sourcepub async fn get_constellation(
&self,
constellation_id: i32,
) -> Result<EsiConstellationInfo>
pub async fn get_constellation( &self, constellation_id: i32, ) -> Result<EsiConstellationInfo>
Fetch constellation info.
Sourcepub async fn get_region(&self, region_id: i32) -> Result<EsiRegionInfo>
pub async fn get_region(&self, region_id: i32) -> Result<EsiRegionInfo>
Fetch region info.
Sourcepub async fn get_station(&self, station_id: i32) -> Result<EsiStationInfo>
pub async fn get_station(&self, station_id: i32) -> Result<EsiStationInfo>
Fetch NPC station info.
Sourcepub async fn get_stargate(&self, stargate_id: i32) -> Result<EsiStargateInfo>
pub async fn get_stargate(&self, stargate_id: i32) -> Result<EsiStargateInfo>
Fetch stargate info.
Sourcepub async fn sovereignty_map(&self) -> Result<Vec<EsiSovereigntyMap>>
pub async fn sovereignty_map(&self) -> Result<Vec<EsiSovereigntyMap>>
Fetch the sovereignty map — who owns each system.
Sourcepub async fn sovereignty_campaigns(&self) -> Result<Vec<EsiSovereigntyCampaign>>
pub async fn sovereignty_campaigns(&self) -> Result<Vec<EsiSovereigntyCampaign>>
Fetch active sovereignty campaigns.
Sourcepub async fn sovereignty_structures(
&self,
) -> Result<Vec<EsiSovereigntyStructure>>
pub async fn sovereignty_structures( &self, ) -> Result<Vec<EsiSovereigntyStructure>>
Fetch sovereignty structures.
Sourcepub async fn get_route(
&self,
origin: i32,
destination: i32,
flag: Option<&str>,
avoid: &[i32],
connections: Option<&[[i32; 2]]>,
) -> Result<Vec<i32>>
pub async fn get_route( &self, origin: i32, destination: i32, flag: Option<&str>, avoid: &[i32], connections: Option<&[[i32; 2]]>, ) -> Result<Vec<i32>>
Calculate a route between two solar systems.
flag controls the pathfinding algorithm: "shortest" (default),
"secure", or "insecure".
avoid is a list of system IDs to avoid.
connections is a list of [from, to] pairs for wormhole connections.
Sourcepub async fn universe_ancestries(&self) -> Result<Vec<EsiAncestry>>
pub async fn universe_ancestries(&self) -> Result<Vec<EsiAncestry>>
Fetch all ancestries.
Sourcepub async fn universe_asteroid_belt(
&self,
asteroid_belt_id: i32,
) -> Result<EsiAsteroidBelt>
pub async fn universe_asteroid_belt( &self, asteroid_belt_id: i32, ) -> Result<EsiAsteroidBelt>
Fetch asteroid belt info.
Sourcepub async fn universe_bloodlines(&self) -> Result<Vec<EsiBloodline>>
pub async fn universe_bloodlines(&self) -> Result<Vec<EsiBloodline>>
Fetch all bloodlines.
Sourcepub async fn list_universe_category_ids(&self) -> Result<Vec<i32>>
pub async fn list_universe_category_ids(&self) -> Result<Vec<i32>>
List all category IDs.
Sourcepub async fn list_universe_constellation_ids(&self) -> Result<Vec<i32>>
pub async fn list_universe_constellation_ids(&self) -> Result<Vec<i32>>
List all constellation IDs.
Sourcepub async fn universe_factions(&self) -> Result<Vec<EsiFaction>>
pub async fn universe_factions(&self) -> Result<Vec<EsiFaction>>
Fetch all factions.
Sourcepub async fn list_universe_graphic_ids(&self) -> Result<Vec<i32>>
pub async fn list_universe_graphic_ids(&self) -> Result<Vec<i32>>
List all graphic IDs.
Sourcepub async fn universe_graphic(&self, graphic_id: i32) -> Result<EsiGraphic>
pub async fn universe_graphic(&self, graphic_id: i32) -> Result<EsiGraphic>
Fetch graphic info.
Sourcepub async fn list_universe_group_ids(&self) -> Result<Vec<i32>>
pub async fn list_universe_group_ids(&self) -> Result<Vec<i32>>
List all group IDs (paginated).
Sourcepub async fn universe_moon(&self, moon_id: i32) -> Result<EsiMoon>
pub async fn universe_moon(&self, moon_id: i32) -> Result<EsiMoon>
Fetch moon info.
Sourcepub async fn universe_planet(&self, planet_id: i32) -> Result<EsiPlanet>
pub async fn universe_planet(&self, planet_id: i32) -> Result<EsiPlanet>
Fetch planet info (universe data, not PI).
Sourcepub async fn universe_races(&self) -> Result<Vec<EsiRace>>
pub async fn universe_races(&self) -> Result<Vec<EsiRace>>
Fetch all races.
Sourcepub async fn list_universe_region_ids(&self) -> Result<Vec<i32>>
pub async fn list_universe_region_ids(&self) -> Result<Vec<i32>>
List all region IDs.
Sourcepub async fn universe_schematic(
&self,
schematic_id: i32,
) -> Result<EsiSchematic>
pub async fn universe_schematic( &self, schematic_id: i32, ) -> Result<EsiSchematic>
Fetch PI schematic info.
Sourcepub async fn universe_star(&self, star_id: i32) -> Result<EsiStar>
pub async fn universe_star(&self, star_id: i32) -> Result<EsiStar>
Fetch star info.
Sourcepub async fn list_public_structure_ids(&self) -> Result<Vec<i64>>
pub async fn list_public_structure_ids(&self) -> Result<Vec<i64>>
List all public structure IDs.
Sourcepub async fn system_jumps(&self) -> Result<Vec<EsiSystemJumps>>
pub async fn system_jumps(&self) -> Result<Vec<EsiSystemJumps>>
Fetch system jump statistics.
Sourcepub async fn system_kills(&self) -> Result<Vec<EsiSystemKills>>
pub async fn system_kills(&self) -> Result<Vec<EsiSystemKills>>
Fetch system kill statistics.
Sourcepub async fn list_universe_system_ids(&self) -> Result<Vec<i32>>
pub async fn list_universe_system_ids(&self) -> Result<Vec<i32>>
List all system IDs.
Sourceimpl EsiClient
impl EsiClient
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new ESI client with the default User-Agent and 30-second timeout.
Panics
Panics if the default user-agent string is invalid (this should never happen as it is a compile-time constant).
Sourcepub fn with_user_agent(user_agent: &str) -> Result<Self>
pub fn with_user_agent(user_agent: &str) -> Result<Self>
Create a new ESI client with a custom User-Agent string and 30-second timeout.
Returns an error if the user-agent string contains invalid HTTP header characters.
ESI requires a descriptive User-Agent. Include your app name, contact info, and optionally your EVE character name. Example:
my-app (contact@example.com; +https://github.com/me/my-app; eve:MyCharacter)Panics
Panics if the reqwest::Client builder fails to build (should not happen
with default settings).
Sourcepub fn with_web_app(
user_agent: &str,
client_id: &str,
client_secret: SecretString,
) -> Result<Self>
pub fn with_web_app( user_agent: &str, client_id: &str, client_secret: SecretString, ) -> Result<Self>
Create an ESI client configured for a web application (confidential client).
Sourcepub fn with_native_app(user_agent: &str, client_id: &str) -> Result<Self>
pub fn with_native_app(user_agent: &str, client_id: &str) -> Result<Self>
Create an ESI client configured for a native/desktop application (public client).
Sourcepub fn credentials(self, creds: EsiAppCredentials) -> Self
pub fn credentials(self, creds: EsiAppCredentials) -> Self
Set app credentials (builder pattern).
Sourcepub fn with_base_url(self, url: impl Into<String>) -> Self
pub fn with_base_url(self, url: impl Into<String>) -> Self
Override the base URL (builder pattern). Useful for testing with mock servers.
Sourcepub fn with_sso_token_url(self, url: impl Into<String>) -> Self
pub fn with_sso_token_url(self, url: impl Into<String>) -> Self
Override the SSO token URL (builder pattern). Useful for testing with mock servers.
Sourcepub fn error_budget(&self) -> i32
pub fn error_budget(&self) -> i32
Return the current error budget value.
Sourcepub fn with_cache(self) -> Self
pub fn with_cache(self) -> Self
Enable the ETag response cache (builder pattern).
Sourcepub fn with_max_cache_entries(self, n: usize) -> Self
pub fn with_max_cache_entries(self, n: usize) -> Self
Set the maximum number of ETag cache entries (builder pattern).
Default is 1000. When the cache is full, an arbitrary entry is evicted.
Sourcepub async fn clear_cache(&self)
pub async fn clear_cache(&self)
Clear all cached ETag responses.
Sourcepub async fn get_paginated<T: DeserializeOwned + Send + 'static>(
&self,
base_url: &str,
) -> Result<Vec<T>>
pub async fn get_paginated<T: DeserializeOwned + Send + 'static>( &self, base_url: &str, ) -> Result<Vec<T>>
Fetch all pages of a paginated GET endpoint and flatten into one Vec.
Sourcepub async fn post_paginated<T, B>(
&self,
base_url: &str,
body: &B,
) -> Result<Vec<T>>
pub async fn post_paginated<T, B>( &self, base_url: &str, body: &B, ) -> Result<Vec<T>>
Fetch all pages of a paginated POST endpoint and flatten into one Vec.
Sourcepub async fn request_cached(&self, url: &str) -> Result<Vec<u8>>
pub async fn request_cached(&self, url: &str) -> Result<Vec<u8>>
Make a GET request with ETag caching support.
Uses execute_request internally for retry/401 handling. On 304,
returns the cached body. On 200, caches the response.
Sourcepub async fn request(&self, url: &str) -> Result<Response>
pub async fn request(&self, url: &str) -> Result<Response>
Make a rate-limited GET request to the given URL.
Sourcepub async fn request_post(
&self,
url: &str,
body: &(impl Serialize + ?Sized),
) -> Result<Response>
pub async fn request_post( &self, url: &str, body: &(impl Serialize + ?Sized), ) -> Result<Response>
Make a rate-limited POST request with a JSON body.
Sourcepub async fn request_delete(&self, url: &str) -> Result<Response>
pub async fn request_delete(&self, url: &str) -> Result<Response>
Make a rate-limited DELETE request.